@@ -116,16 +116,13 @@ class Response(object):
         if 'charset' in kw:
             charset = kw.pop('charset')
         elif self.default_charset:
-            if (content_type
-                and 'charset=' not in content_type
-                and (content_type == 'text/html'
-                    or content_type.startswith('text/')
-                    or content_type.startswith('application/xml')
-                    or content_type.startswith('application/json')
-                    or (content_type.startswith('application/')
-                         and (content_type.endswith('+xml') or content_type.endswith('+json'))))):
-                charset = self.default_charset
-        if content_type and charset:
+            if content_type and 'charset=' not in content_type:
+                if (content_type == 'text/html'
+                        or content_type.startswith('text/')
+                        or _is_xml(content_type)
+                        or _is_json(content_type)):
+                    charset = self.default_charset
+        if content_type and charset and not _is_json(content_type):
             content_type += '; charset=' + charset
         elif self._headerlist and charset:
             self.charset = charset
@@ -179,7 +176,7 @@ class Response(object):
             _http = b'HTTP/'
 
         if status.startswith(_http):
-            (http_ver, status_num, status_text) = status.split()
+            (http_ver, status_num, status_text) = status.split(None, 2)
             status = '%s %s' % (native_(status_num), native_(status_text))
 
         while 1:
@@ -1251,6 +1248,16 @@ class EmptyResponse(object):
 
     __next__ = next # py3
 
+def _is_json(content_type):
+    return (content_type.startswith('application/json')
+            or (content_type.startswith('application/')
+                and content_type.endswith('+json')))
+
+def _is_xml(content_type):
+    return (content_type.startswith('application/xml')
+            or (content_type.startswith('application/')
+                and content_type.endswith('+xml')))
+
 def _request_uri(environ):
     """Like wsgiref.url.request_uri, except eliminates :80 ports
 
